@@ -16,7 +16,7 @@ class SingleScheduledEvent:
         if not self.schedule_id:
             return
 
-        api.post(path=f'scheduler/{self.schedule_id}/completed')
+        api.post(path=f'/scheduler/{self.schedule_id}/completed')
 
 
 class ScheduledEvent(Event):
